# Wet changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### 0.1.2 - 2025-03-34
- Fix: follow symlinks 
- Fix: display version
- rename package to allow publishing on Pypi

### 0.1.0 - 2025-03-21
- First publication of wet
- Most `get` features
- Some `list` and `show` features
- Packaging